BlockHeader

Struct BlockHeader 

pub struct BlockHeader {
    pub version: i32,
    pub prev_blockhash: BlockHash,
    pub merkle_root: TxMerkleNode,
    pub im_merkle_root: TxMerkleNode,
    pub time: u32,
    pub xfield: XField,
    pub proof: Option<Signature>,
}
A block header, which contains all the block’s information except the actual transactions

Fields

version: i32

The protocol version. Should always be 1.

prev_blockhash: BlockHash

Reference to the previous block in the chain

merkle_root: TxMerkleNode

The root hash of the merkle tree of transactions in the block

im_merkle_root: TxMerkleNode

MerkleRoot based on fixing malleability transaction hash

time: u32

The timestamp of the block, as claimed by the miner

xfield: XField

Extra field. This field can host any type of data defined in Tapyrus protocol.

proof: Option<Signature>

Collection holds a signature for block hash which is consisted of block header without Proof.

Implementations

Source

impl BlockHeader

pub fn block_hash(&self) -> BlockHash

Return the block hash.

pub fn aggregated_public_key(&self) -> Option<PublicKey>

Return the Aggregate public key in this BlockHeader

pub fn max_block_size(&self) -> Option<u32>

Return the max block size in this BlockHeader

pub fn signature_hash(&self) -> BlockSigHash

Computes a signature hash for this block. Tapyrus signer needs to sign this hash. The signature will be added to the block header as the proof field and submitted to the tapyrus node.

pub fn get_size(&self) -> usize

Return block header size