Struct tapyrus::util::key::PublicKey [−][src]
A Bitcoin ECDSA public key
Fields
compressed: boolWhether this public key should be serialized as compressed
key: PublicKeyThe actual ECDSA key
Implementations
impl PublicKey[src]
pub fn write_into<W: Write>(&self, writer: W)[src]
Write the public key into a writer
pub fn to_bytes(&self) -> Vec<u8>[src]
Serialize the public key to bytes
pub fn from_slice(data: &[u8]) -> Result<PublicKey, Error>[src]
Deserialize a public key from a slice
pub fn from_private_key<C: Signing>(
secp: &Secp256k1<C>,
sk: &PrivateKey
) -> PublicKey[src]
secp: &Secp256k1<C>,
sk: &PrivateKey
) -> PublicKey
Computes the public key as supposed to be used with this secret
pub fn generator() -> PublicKey[src]
Returns generator point of secp256k1 as PublicKey