Module tapyrus::util::misc[][src]

Miscellaneous functions

Various utility functions

Functions

script_find_and_remove

Search for needle in the vector haystack and remove every instance of it, returning the number of instances removed. Loops through the vector opcode by opcode, skipping pushed data.

signed_msg_hash

Hash message for signature using Bitcoin's message signing format