Struct tapyrus::util::psbt::Input [−][src]
A key-value map for an input of the corresponding index in the unsigned transaction.
Fields
non_witness_utxo: Option<Transaction>The non-witness transaction this input spends from. Should only be std::option::Option::Some for inputs which spend non-segwit outputs or if it is unknown whether an input spends a segwit output.
witness_utxo: Option<TxOut>The transaction output this input spends from. Should only be std::option::Option::Some for inputs which spend segwit outputs, including P2SH embedded ones.
partial_sigs: BTreeMap<PublicKey, Vec<u8>>A map from public keys to their corresponding signature as would be pushed to the stack from a scriptSig or witness.
sighash_type: Option<SigHashType>The sighash type to be used for this input. Signatures for this input must use the sighash type.
redeem_script: Option<Script>The redeem script for this input.
witness_script: Option<Script>The witness script for this input.
hd_keypaths: BTreeMap<PublicKey, (Fingerprint, DerivationPath)>A map from public keys needed to sign this input to their corresponding master key fingerprints and derivation paths.
final_script_sig: Option<Script>The finalized, fully-constructed scriptSig with signatures and any other scripts necessary for this input to pass validation.
final_script_witness: Option<Vec<Vec<u8>>>The finalized, fully-constructed scriptWitness with signatures and any other scripts necessary for this input to pass validation.
unknown: BTreeMap<Key, Vec<u8>>Unknown key-value pairs for this input.