Struct tapyrus::util::address::Address [−][src]
A Bitcoin address
Fields
payload: PayloadThe type of the address
network: NetworkThe network on which this address is usable
Implementations
impl Address[src]
pub fn p2pkh(pk: &PublicKey, network: Network) -> Address[src]
Creates a pay to (compressed) public key hash address from a public key This is the preferred non-witness type address
pub fn p2sh(script: &Script, network: Network) -> Address[src]
Creates a pay to script hash P2SH address from a script This address type was introduced with BIP16 and is the popular type to implement multi-sig these days.
pub fn address_type(&self) -> Option<AddressType>[src]
Get the address type of the address. None if unknown or non-standard.
pub fn is_standard(&self) -> bool[src]
Check whether or not the address is following Bitcoin standardness rules.
Segwit addresses with unassigned witness versions or non-standard program sizes are considered non-standard.
pub fn from_script(script: &Script, network: Network) -> Option<Address>[src]
Get an Address from an output script (scriptPubkey).
pub fn script_pubkey(&self) -> Script[src]
Generates a script pubkey spending to this address