Struct tapyrus::util::key::PrivateKey [−][src]
A Bitcoin ECDSA private key
Fields
compressed: boolWhether this private key should be serialized as compressed
network: NetworkThe network on which this key should be used
key: SecretKeyThe actual ECDSA key
Implementations
impl PrivateKey[src]
pub fn public_key<C: Signing>(&self, secp: &Secp256k1<C>) -> PublicKey[src]
Creates a public key from this private key
pub fn to_bytes(&self) -> Vec<u8>[src]
Serialize the private key to bytes
pub fn fmt_wif(&self, fmt: &mut dyn Write) -> Result[src]
Format the private key to WIF format.
pub fn to_wif(&self) -> String[src]
Get WIF encoding of this private key.
pub fn from_wif(wif: &str) -> Result<PrivateKey, Error>[src]
Parse WIF encoded private key.